#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SHIFT_RIGHT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SHIFT_RIGHT_HPP_INCLUDED

#include <boost/simd/operator/include/functions/shift_right.hpp>

#endif
